Changelog
=========

0.0.1 (2018-04-24)
------------------

- Rename module to json_tag


0.0.0 (2018-04-24)
------------------

Initial release:

- Extracted from django-argonauts
- `{% json %}` tag
- escape single quote
- fix travis tests
